@@ -24,29 +24,35 @@
 	Virtual file operations for the Audio File Library.
 */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "afinternal.h"
 #include "af_vfs.h"
 
 #include <stdlib.h>
 
-AF_VirtualFile *
+AFvirtualfile *
 af_virtual_file_new(void)
 {
-  return (AF_VirtualFile *) calloc(sizeof (AF_VirtualFile), 1);
+  return (AFvirtualfile *) calloc(sizeof (AFvirtualfile), 1);
 }
 
 void
-af_virtual_file_destroy(AF_VirtualFile *vfile)
+af_virtual_file_destroy(AFvirtualfile *vfile)
 {
   vfile->destroy(vfile);
 
   free(vfile);
 }
 
-size_t
-af_fread(void *data, size_t size, size_t nmemb, AF_VirtualFile *vfile)
+size_t af_fread (void *data, size_t size, size_t nmemb, AFvirtualfile *vfile)
 {
-  if(vfile->read) {
+  if (size == 0 || nmemb == 0)
+    return 0;
+
+  if (vfile->read) {
     int retval;
 
     retval = (* vfile->read) (vfile, data, size * nmemb);
@@ -56,10 +62,13 @@ af_fread(void *data, size_t size, size_t nmemb, AF_VirtualFile *vfile)
     return 0;
 }
 
-size_t
-af_fwrite(const void *data, size_t size, size_t nmemb, AF_VirtualFile *vfile)
+size_t af_fwrite (const void *data, size_t size, size_t nmemb,
+	AFvirtualfile *vfile)
 {
-  if(vfile->write) {
+  if (size == 0 || nmemb == 0)
+    return 0;
+
+  if (vfile->write) {
     int retval;
 
     retval = (* vfile->write) (vfile, data, size * nmemb);
@@ -70,7 +79,7 @@ af_fwrite(const void *data, size_t size, size_t nmemb, AF_VirtualFile *vfile)
 }
 
 int
-af_fclose(AF_VirtualFile *vfile)
+af_fclose(AFvirtualfile *vfile)
 {
   af_virtual_file_destroy(vfile);
 
@@ -78,7 +87,7 @@ af_fclose(AF_VirtualFile *vfile)
 }
 
 long
-af_flength(AF_VirtualFile *vfile)
+af_flength(AFvirtualfile *vfile)
 {
   if(vfile->length)
     return (* vfile->length)(vfile);
@@ -87,7 +96,7 @@ af_flength(AF_VirtualFile *vfile)
 }
 
 int
-af_fseek(AF_VirtualFile *vfile, long offset, int whence)
+af_fseek(AFvirtualfile *vfile, long offset, int whence)
 {
   if(whence == SEEK_CUR)
     (* vfile->seek) (vfile, offset, 1);
@@ -100,7 +109,7 @@ af_fseek(AF_VirtualFile *vfile, long offset, int whence)
 }
 
 long
-af_ftell(AF_VirtualFile *vfile)
+af_ftell(AFvirtualfile *vfile)
 {
   if(vfile->tell)
     return (* vfile->tell)(vfile);
@@ -108,17 +117,18 @@ af_ftell(AF_VirtualFile *vfile)
     return 0;
 }
 
-static int af_file_read(AF_VirtualFile *vfile, unsigned char *data, int nbytes);
-static long af_file_length(AF_VirtualFile *vfile);
-static int af_file_write(AF_VirtualFile *vfile, const unsigned char *data, int nbytes);
-static void af_file_destroy(AF_VirtualFile *vfile);
-static long af_file_seek(AF_VirtualFile *vfile, long offset, int is_relative);
-static long af_file_tell(AF_VirtualFile *vfile);
+static ssize_t af_file_read (AFvirtualfile *vfile, void *data, size_t nbytes);
+static long af_file_length (AFvirtualfile *vfile);
+static ssize_t af_file_write (AFvirtualfile *vfile, const void *data,
+	size_t nbytes);
+static void af_file_destroy(AFvirtualfile *vfile);
+static long af_file_seek(AFvirtualfile *vfile, long offset, int is_relative);
+static long af_file_tell(AFvirtualfile *vfile);
 
-AF_VirtualFile *
+AFvirtualfile *
 af_virtual_file_new_for_file(FILE *fh)
 {
-  AF_VirtualFile *vf;
+  AFvirtualfile *vf;
 
   if(!fh)
     return NULL;
@@ -135,14 +145,13 @@ af_virtual_file_new_for_file(FILE *fh)
   return vf;
 }
 
-static int
-af_file_read(AF_VirtualFile *vfile, unsigned char *data, int nbytes)
+static ssize_t af_file_read(AFvirtualfile *vfile, void *data, size_t nbytes)
 {
-  return fread(data, 1, nbytes, vfile->closure);
+	return fread(data, 1, nbytes, vfile->closure);
 }
 
 static long
-af_file_length(AF_VirtualFile *vfile)
+af_file_length(AFvirtualfile *vfile)
 {
   long curpos, retval;
 
@@ -154,20 +163,20 @@ af_file_length(AF_VirtualFile *vfile)
   return retval;
 }
 
-static int
-af_file_write(AF_VirtualFile *vfile, const unsigned char *data, int nbytes)
+static ssize_t af_file_write (AFvirtualfile *vfile, const void *data,
+	size_t nbytes)
 {
-  return fwrite(data, 1, nbytes, vfile->closure);
+	return fwrite(data, 1, nbytes, vfile->closure);
 }
 
 static void
-af_file_destroy(AF_VirtualFile *vfile)
+af_file_destroy(AFvirtualfile *vfile)
 {
   fclose(vfile->closure); vfile->closure = NULL;
 }
 
 static long
-af_file_seek(AF_VirtualFile *vfile, long offset, int is_relative)
+af_file_seek(AFvirtualfile *vfile, long offset, int is_relative)
 {
   fseek(vfile->closure, offset, is_relative?SEEK_CUR:SEEK_SET);
 
@@ -175,7 +184,7 @@ af_file_seek(AF_VirtualFile *vfile, long offset, int is_relative)
 }
 
 static long
-af_file_tell(AF_VirtualFile *vfile)
+af_file_tell(AFvirtualfile *vfile)
 {
   return ftell(vfile->closure);
 }
