@@ -30,15 +30,10 @@
 #endif
 
 #include <assert.h>
-#include <sys/types.h>
-#include <stdio.h>
+#include <math.h>
+#include <stdint.h>
 #include <stdlib.h>
 #include <string.h>
-#include <math.h>
-
-#ifdef HAVE_INTTYPES_H
-#include <inttypes.h>
-#endif
 
 #include "audiofile.h"
 #include "util.h"
@@ -49,13 +44,13 @@
 #include "setup.h"
 #include "marker.h"
 
-int _af_wave_compression_types[_AF_WAVE_NUM_COMPTYPES] =
+const int _af_wave_compression_types[_AF_WAVE_NUM_COMPTYPES] =
 {
 	AF_COMPRESSION_G711_ULAW,
 	AF_COMPRESSION_G711_ALAW
 };
 
-_InstParamInfo _af_wave_inst_params[_AF_WAVE_NUM_INSTPARAMS] =
+const _InstParamInfo _af_wave_inst_params[_AF_WAVE_NUM_INSTPARAMS] =
 {
 	{ AF_INST_MIDI_BASENOTE, AU_PVTYPE_LONG, "MIDI base note", {60} },
 	{ AF_INST_NUMCENTS_DETUNE, AU_PVTYPE_LONG, "Detune in cents", {0} },
@@ -70,9 +65,9 @@ _AFfilesetup _af_wave_default_filesetup =
 {
 	_AF_VALID_FILESETUP,	/* valid */
 	AF_FILE_WAVE,		/* fileFormat */
-	AF_TRUE,		/* trackSet */
-	AF_TRUE,		/* instrumentSet */
-	AF_TRUE,		/* miscellaneousSet  */
+	true,			/* trackSet */
+	true,			/* instrumentSet */
+	true,			/* miscellaneousSet  */
 	1,			/* trackCount */
 	NULL,			/* tracks */
 	0,			/* instrumentCount */
@@ -82,27 +77,27 @@ _AFfilesetup _af_wave_default_filesetup =
 };
 
 static status ParseFrameCount (AFfilehandle filehandle, AFvirtualfile *fp,
-	u_int32_t id, size_t size)
+	uint32_t id, size_t size)
 {
-	u_int32_t	totalFrames;
+	uint32_t	totalFrames;
 	_Track		*track;
 
 	track = _af_filehandle_get_track(filehandle, AF_DEFAULT_TRACK);
 
-	af_fread(&totalFrames, 1, 4, fp);
+	af_read_uint32_le(&totalFrames, fp);
 
-	track->totalfframes = LENDIAN_TO_HOST_INT32(totalFrames);
+	track->totalfframes = totalFrames;
 
 	return AF_SUCCEED;
 }
 
 static status ParseFormat (AFfilehandle filehandle, AFvirtualfile *fp,
-	u_int32_t id, size_t size)
+	uint32_t id, size_t size)
 {
 	_Track		*track;
-	u_int16_t	formatTag, channelCount;
-	u_int32_t	sampleRate, averageBytesPerSecond;
-	u_int16_t	blockAlign;
+	uint16_t	formatTag, channelCount;
+	uint32_t	sampleRate, averageBytesPerSecond;
+	uint16_t	blockAlign;
 	_WAVEInfo	*wave;
 
 	assert(filehandle != NULL);
@@ -114,23 +109,14 @@ static status ParseFormat (AFfilehandle filehandle, AFvirtualfile *fp,
 	assert(filehandle->formatSpecific != NULL);
 	wave = (_WAVEInfo *) filehandle->formatSpecific;
 
-	af_fread(&formatTag, 1, 2, fp);
-	formatTag = LENDIAN_TO_HOST_INT16(formatTag);
+	af_read_uint16_le(&formatTag, fp);
+	af_read_uint16_le(&channelCount, fp);
+	af_read_uint32_le(&sampleRate, fp);
+	af_read_uint32_le(&averageBytesPerSecond, fp);
+	af_read_uint16_le(&blockAlign, fp);
 
-	af_fread(&channelCount, 1, 2, fp);
-	channelCount = LENDIAN_TO_HOST_INT16(channelCount);
 	track->f.channelCount = channelCount;
-
-	af_fread(&sampleRate, 1, 4, fp);
-	sampleRate = LENDIAN_TO_HOST_INT32(sampleRate);
 	track->f.sampleRate = sampleRate;
-
-	af_fread(&averageBytesPerSecond, 1, 4, fp);
-	averageBytesPerSecond = LENDIAN_TO_HOST_INT32(averageBytesPerSecond);
-
-	af_fread(&blockAlign, 1, 2, fp);
-	blockAlign = LENDIAN_TO_HOST_INT16(blockAlign);
-
 	track->f.byteOrder = AF_BYTEORDER_LITTLEENDIAN;
 
 	/* Default to uncompressed audio data. */
@@ -140,10 +126,9 @@ static status ParseFormat (AFfilehandle filehandle, AFvirtualfile *fp,
 	{
 		case WAVE_FORMAT_PCM:
 		{
-			u_int16_t	bitsPerSample;
+			uint16_t	bitsPerSample;
 
-			af_fread(&bitsPerSample, 1, 2, fp);
-			bitsPerSample = LENDIAN_TO_HOST_INT16(bitsPerSample);
+			af_read_uint16_le(&bitsPerSample, fp);
 
 			track->f.sampleWidth = bitsPerSample;
 
@@ -178,10 +163,9 @@ static status ParseFormat (AFfilehandle filehandle, AFvirtualfile *fp,
 
 		case WAVE_FORMAT_IEEE_FLOAT:
 		{
-			u_int16_t	bitsPerSample;
+			uint16_t	bitsPerSample;
 
-			af_fread(&bitsPerSample, 1, 2, fp);
-			bitsPerSample = LENDIAN_TO_HOST_INT16(bitsPerSample);
+			af_read_uint16_le(&bitsPerSample, fp);
 
 			if (bitsPerSample == 64)
 			{
@@ -198,7 +182,7 @@ static status ParseFormat (AFfilehandle filehandle, AFvirtualfile *fp,
 
 		case WAVE_FORMAT_ADPCM:
 		{
-			u_int16_t	bitsPerSample, extraByteCount,
+			uint16_t	bitsPerSample, extraByteCount,
 					samplesPerBlock, numCoefficients;
 			int		i;
 			AUpvlist	pv;
@@ -213,17 +197,10 @@ static status ParseFormat (AFfilehandle filehandle, AFvirtualfile *fp,
 					"must have 1 or 2 channels");
 			}
 
-			af_fread(&bitsPerSample, 1, 2, fp);
-			bitsPerSample = LENDIAN_TO_HOST_INT16(bitsPerSample);
-
-			af_fread(&extraByteCount, 1, 2, fp);
-			extraByteCount = LENDIAN_TO_HOST_INT16(extraByteCount);
-
-			af_fread(&samplesPerBlock, 1, 2, fp);
-			samplesPerBlock = LENDIAN_TO_HOST_INT16(samplesPerBlock);
-
-			af_fread(&numCoefficients, 1, 2, fp);
-			numCoefficients = LENDIAN_TO_HOST_INT16(numCoefficients);
+			af_read_uint16_le(&bitsPerSample, fp);
+			af_read_uint16_le(&extraByteCount, fp);
+			af_read_uint16_le(&samplesPerBlock, fp);
+			af_read_uint16_le(&numCoefficients, fp);
 
 			/* numCoefficients should be at least 7. */
 			assert(numCoefficients >= 7 && numCoefficients <= 255);
@@ -232,11 +209,8 @@ static status ParseFormat (AFfilehandle filehandle, AFvirtualfile *fp,
 			{
 				int16_t	a0, a1;
 
-				af_fread(&a0, 1, 2, fp);
-				af_fread(&a1, 1, 2, fp);
-
-				a0 = LENDIAN_TO_HOST_INT16(a0);
-				a1 = LENDIAN_TO_HOST_INT16(a1);
+				af_read_uint16_le(&a0, fp);
+				af_read_uint16_le(&a1, fp);
 
 				wave->msadpcmCoefficients[i][0] = a0;
 				wave->msadpcmCoefficients[i][1] = a1;
@@ -259,7 +233,7 @@ static status ParseFormat (AFfilehandle filehandle, AFvirtualfile *fp,
 			v = wave->msadpcmCoefficients;
 			AUpvsetval(pv, 1, &v);
 
-			AUpvsetparam(pv, 2, _AF_SAMPLES_PER_BLOCK);
+			AUpvsetparam(pv, 2, _AF_FRAMES_PER_BLOCK);
 			AUpvsetvaltype(pv, 2, AU_PVTYPE_LONG);
 			l = samplesPerBlock;
 			AUpvsetval(pv, 2, &l);
@@ -278,17 +252,25 @@ static status ParseFormat (AFfilehandle filehandle, AFvirtualfile *fp,
 			AUpvlist	pv;
 			long		l;
 
-			u_int16_t	bitsPerSample, extraByteCount,
+			uint16_t	bitsPerSample, extraByteCount,
 					samplesPerBlock;
 
-			af_fread(&bitsPerSample, 1, 2, fp);
-			bitsPerSample = LENDIAN_TO_HOST_INT16(bitsPerSample);
+			af_read_uint16_le(&bitsPerSample, fp);
+			af_read_uint16_le(&extraByteCount, fp);
+			af_read_uint16_le(&samplesPerBlock, fp);
 
-			af_fread(&extraByteCount, 1, 2, fp);
-			extraByteCount = LENDIAN_TO_HOST_INT16(extraByteCount);
+			if (bitsPerSample != 4)
+			{
+				_af_error(AF_BAD_NOT_IMPLEMENTED,
+					"IMA ADPCM compression supports only 4 bits per sample");
+			}
 
-			af_fread(&samplesPerBlock, 1, 2, fp);
-			samplesPerBlock = LENDIAN_TO_HOST_INT16(samplesPerBlock);
+			int bytesPerBlock = (samplesPerBlock + 14) / 8 * 4 * channelCount;
+			if (bytesPerBlock > blockAlign || (samplesPerBlock % 8) != 1)
+			{
+				_af_error(AF_BAD_CODEC_CONFIG,
+					"Invalid samples per block for IMA ADPCM compression");
+			}
 
 			track->f.sampleWidth = 16;
 			track->f.sampleFormat = AF_SAMPFMT_TWOSCOMP;
@@ -297,7 +279,7 @@ static status ParseFormat (AFfilehandle filehandle, AFvirtualfile *fp,
 
 			/* Create the parameter list. */
 			pv = AUpvnew(2);
-			AUpvsetparam(pv, 0, _AF_SAMPLES_PER_BLOCK);
+			AUpvsetparam(pv, 0, _AF_FRAMES_PER_BLOCK);
 			AUpvsetvaltype(pv, 0, AU_PVTYPE_LONG);
 			l = samplesPerBlock;
 			AUpvsetval(pv, 0, &l);
@@ -341,7 +323,7 @@ static status ParseFormat (AFfilehandle filehandle, AFvirtualfile *fp,
 }
 
 static status ParseData (AFfilehandle filehandle, AFvirtualfile *fp,
-	u_int32_t id, size_t size)
+	uint32_t id, size_t size)
 {
 	_Track	*track;
 
@@ -358,14 +340,13 @@ static status ParseData (AFfilehandle filehandle, AFvirtualfile *fp,
 }
 
 static status ParsePlayList (AFfilehandle filehandle, AFvirtualfile *fp,
-	u_int32_t id, size_t size)
+	uint32_t id, size_t size)
 {
 	_Instrument	*instrument;
-	u_int32_t	segmentCount;
+	uint32_t	segmentCount;
 	int		segment;
 
-	af_fread(&segmentCount, 4, 1, fp);
-	segmentCount = LENDIAN_TO_HOST_INT32(segmentCount);
+	af_read_uint32_le(&segmentCount, fp);
 
 	if (segmentCount == 0)
 	{
@@ -376,30 +357,26 @@ static status ParsePlayList (AFfilehandle filehandle, AFvirtualfile *fp,
 
 	for (segment=0; segment<segmentCount; segment++)
 	{
-		u_int32_t	startMarkID, loopLength, loopCount;
+		uint32_t	startMarkID, loopLength, loopCount;
 
-		af_fread(&startMarkID, 4, 1, fp);
-		startMarkID = LENDIAN_TO_HOST_INT32(startMarkID);
-		af_fread(&loopLength, 4, 1, fp);
-		loopLength = LENDIAN_TO_HOST_INT32(loopLength);
-		af_fread(&loopCount, 4, 1, fp);
-		loopCount = LENDIAN_TO_HOST_INT32(loopCount);
+		af_read_uint32_le(&startMarkID, fp);
+		af_read_uint32_le(&loopLength, fp);
+		af_read_uint32_le(&loopCount, fp);
 	}
 
 	return AF_SUCCEED;
 }
 
 static status ParseCues (AFfilehandle filehandle, AFvirtualfile *fp,
-	u_int32_t id, size_t size)
+	uint32_t id, size_t size)
 {
 	_Track		*track;
-	u_int32_t	markerCount;
+	uint32_t	markerCount;
 	int		i;
 
 	track = _af_filehandle_get_track(filehandle, AF_DEFAULT_TRACK);
 
-	af_fread(&markerCount, 4, 1, fp);
-	markerCount = LENDIAN_TO_HOST_INT32(markerCount);
+	af_read_uint32_le(&markerCount, fp);
 	track->markerCount = markerCount;
 
 	if (markerCount == 0)
@@ -413,32 +390,22 @@ static status ParseCues (AFfilehandle filehandle, AFvirtualfile *fp,
 
 	for (i=0; i<markerCount; i++)
 	{
-		u_int32_t	id, position, chunkid;
-		u_int32_t	chunkByteOffset, blockByteOffset;
-		u_int32_t	sampleFrameOffset;
+		uint32_t	id, position, chunkid;
+		uint32_t	chunkByteOffset, blockByteOffset;
+		uint32_t	sampleFrameOffset;
 		_Marker		*marker = &track->markers[i];
 
-		af_fread(&id, 4, 1, fp);
-		id = LENDIAN_TO_HOST_INT32(id);
-
-		af_fread(&position, 4, 1, fp);
-		position = LENDIAN_TO_HOST_INT32(position);
-
-		af_fread(&chunkid, 4, 1, fp);
-		chunkid = LENDIAN_TO_HOST_INT32(chunkid);
-
-		af_fread(&chunkByteOffset, 4, 1, fp);
-		chunkByteOffset = LENDIAN_TO_HOST_INT32(chunkByteOffset);
-
-		af_fread(&blockByteOffset, 4, 1, fp);
-		blockByteOffset = LENDIAN_TO_HOST_INT32(blockByteOffset);
+		af_read_uint32_le(&id, fp);
+		af_read_uint32_le(&position, fp);
+		af_read_uint32_le(&chunkid, fp);
+		af_read_uint32_le(&chunkByteOffset, fp);
+		af_read_uint32_le(&blockByteOffset, fp);
 
 		/*
 			sampleFrameOffset represents the position of
 			the mark in units of frames.
 		*/
-		af_fread(&sampleFrameOffset, 4, 1, fp);
-		sampleFrameOffset = LENDIAN_TO_HOST_INT32(sampleFrameOffset);
+		af_read_uint32_le(&sampleFrameOffset, fp);
 
 		marker->id = id;
 		marker->position = sampleFrameOffset;
@@ -451,7 +418,7 @@ static status ParseCues (AFfilehandle filehandle, AFvirtualfile *fp,
 
 /* Parse an adtl sub-chunk within a LIST chunk. */
 static status ParseADTLSubChunk (AFfilehandle filehandle, AFvirtualfile *fp,
-	u_int32_t id, size_t size)
+	uint32_t id, size_t size)
 {
 	_Track		*track;
 	AFfileoffset	endPos=af_ftell(fp)+size;
@@ -461,24 +428,21 @@ static status ParseADTLSubChunk (AFfilehandle filehandle, AFvirtualfile *fp,
 	while (af_ftell(fp) < endPos)
 	{
 		char		chunkID[4];
-		u_int32_t	chunkSize;
+		uint32_t	chunkSize;
 
 		af_fread(chunkID, 4, 1, fp);
-		af_fread(&chunkSize, 4, 1, fp);
-		chunkSize = LENDIAN_TO_HOST_INT32(chunkSize);
+		af_read_uint32_le(&chunkSize, fp);
 
 		if (memcmp(chunkID, "labl", 4)==0 || memcmp(chunkID, "note", 4)==0)
 		{
 			_Marker *marker=NULL;
-			u_int32_t id;
+			uint32_t id;
 			long length=chunkSize-4;
 			char *p=_af_malloc(length);
 
-			af_fread(&id, 4, 1, fp);
+			af_read_uint32_le(&id, fp);
 			af_fread(p, length, 1, fp);
 
-			id = LENDIAN_TO_HOST_INT32(id);
-
 			marker = _af_marker_find_by_id(track, id);
 
 			if (marker != NULL)
@@ -517,18 +481,17 @@ static status ParseADTLSubChunk (AFfilehandle filehandle, AFvirtualfile *fp,
 
 /* Parse an INFO sub-chunk within a LIST chunk. */
 static status ParseINFOSubChunk (AFfilehandle filehandle, AFvirtualfile *fp,
-	u_int32_t id, size_t size)
+	uint32_t id, size_t size)
 {
 	AFfileoffset	endPos=af_ftell(fp)+size;
 
 	while (af_ftell(fp) < endPos)
 	{
 		int		misctype = AF_MISC_UNRECOGNIZED;
-		u_int32_t	miscid, miscsize;
+		uint32_t	miscid, miscsize;
 
 		af_fread(&miscid, 4, 1, fp);
-		af_fread(&miscsize, 4, 1, fp);
-		miscsize = LENDIAN_TO_HOST_INT32(miscsize);
+		af_read_uint32_le(&miscsize, fp);
 
 		if (memcmp(&miscid, "IART", 4) == 0)
 			misctype = AF_MISC_AUTH;
@@ -571,9 +534,9 @@ static status ParseINFOSubChunk (AFfilehandle filehandle, AFvirtualfile *fp,
 }
 
 static status ParseList (AFfilehandle filehandle, AFvirtualfile *fp,
-	u_int32_t id, size_t size)
+	uint32_t id, size_t size)
 {
-	u_int32_t	typeID;
+	uint32_t	typeID;
 
 	af_fread(&typeID, 4, 1, fp);
 	size-=4;
@@ -598,44 +561,44 @@ static status ParseList (AFfilehandle filehandle, AFvirtualfile *fp,
 }
 
 static status ParseInstrument (AFfilehandle filehandle, AFvirtualfile *fp,
-	u_int32_t id, size_t size)
+	uint32_t id, size_t size)
 {
-	u_int8_t	baseNote;
-	int8_t		detune, gain;
-	u_int8_t	lowNote, highNote, lowVelocity, highVelocity;
-	u_int8_t	padByte;
+	uint8_t	baseNote;
+	int8_t	detune, gain;
+	uint8_t	lowNote, highNote, lowVelocity, highVelocity;
+	uint8_t	padByte;
 
-	af_fread(&baseNote, 1, 1, fp);
-	af_fread(&detune, 1, 1, fp);
-	af_fread(&gain, 1, 1, fp);
-	af_fread(&lowNote, 1, 1, fp);
-	af_fread(&highNote, 1, 1, fp);
-	af_fread(&lowVelocity, 1, 1, fp);
-	af_fread(&highVelocity, 1, 1, fp);
-	af_fread(&padByte, 1, 1, fp);
+	af_read_uint8(&baseNote, fp);
+	af_read_uint8(&detune, fp);
+	af_read_uint8(&gain, fp);
+	af_read_uint8(&lowNote, fp);
+	af_read_uint8(&highNote, fp);
+	af_read_uint8(&lowVelocity, fp);
+	af_read_uint8(&highVelocity, fp);
+	af_read_uint8(&padByte, fp);
 
 	return AF_SUCCEED;
 }
 
 bool _af_wave_recognize (AFvirtualfile *fh)
 {
-	u_int8_t	buffer[8];
+	uint8_t	buffer[8];
 
 	af_fseek(fh, 0, SEEK_SET);
 
 	if (af_fread(buffer, 1, 8, fh) != 8 || memcmp(buffer, "RIFF", 4) != 0)
-		return AF_FALSE;
+		return false;
 	if (af_fread(buffer, 1, 4, fh) != 4 || memcmp(buffer, "WAVE", 4) != 0)
-		return AF_FALSE;
+		return false;
 
-	return AF_TRUE;
+	return true;
 }
 
 status _af_wave_read_init (AFfilesetup setup, AFfilehandle filehandle)
 {
 	_Track		*track;
-	u_int32_t	type, size, formtype;
-	u_int32_t	index = 0;
+	uint32_t	type, size, formtype;
+	uint32_t	index = 0;
 	bool		hasFormat, hasData, hasCue, hasList, hasPlayList, hasFrameCount,
 			hasINST, hasINFO;
 	_WAVEInfo	*wave = _af_malloc(sizeof (_WAVEInfo));
@@ -643,14 +606,14 @@ status _af_wave_read_init (AFfilesetup setup, AFfilehandle filehandle)
 	assert(filehandle != NULL);
 	assert(filehandle->fh != NULL);
 
-	hasFormat = AF_FALSE;
-	hasData = AF_FALSE;
-	hasCue = AF_FALSE;
-	hasList = AF_FALSE;
-	hasPlayList = AF_FALSE;
-	hasFrameCount = AF_FALSE;
-	hasINST = AF_FALSE;
-	hasINFO = AF_FALSE;
+	hasFormat = false;
+	hasData = false;
+	hasCue = false;
+	hasList = false;
+	hasPlayList = false;
+	hasFrameCount = false;
+	hasINST = false;
+	hasINFO = false;
 
 	filehandle->formatSpecific = wave;
 	filehandle->instruments = NULL;
@@ -665,8 +628,7 @@ status _af_wave_read_init (AFfilesetup setup, AFfilehandle filehandle)
 	af_fseek(filehandle->fh, 0, SEEK_SET);
 
 	af_fread(&type, 4, 1, filehandle->fh);
-	af_fread(&size, 4, 1, filehandle->fh);
-	size = LENDIAN_TO_HOST_INT32(size);
+	af_read_uint32_le(&size, filehandle->fh);
 	af_fread(&formtype, 4, 1, filehandle->fh);
 
 	assert(!memcmp(&type, "RIFF", 4));
@@ -681,16 +643,14 @@ status _af_wave_read_init (AFfilesetup setup, AFfilehandle filehandle)
 
 	while (index < size)
 	{
-		u_int32_t	chunkid = 0, chunksize = 0;
+		uint32_t	chunkid = 0, chunksize = 0;
 		status		result;
 
 #ifdef DEBUG
 		printf("index: %d\n", index);
 #endif
 		af_fread(&chunkid, 4, 1, filehandle->fh);
-
-		af_fread(&chunksize, 4, 1, filehandle->fh);
-		chunksize = LENDIAN_TO_HOST_INT32(chunksize);
+		af_read_uint32_le(&chunksize, filehandle->fh);
 
 #ifdef DEBUG
 		_af_printid(BENDIAN_TO_HOST_INT32(chunkid));
@@ -703,7 +663,7 @@ status _af_wave_read_init (AFfilesetup setup, AFfilehandle filehandle)
 			if (result == AF_FAIL)
 				return AF_FAIL;
 
-			hasFormat = AF_TRUE;
+			hasFormat = true;
 		}
 		else if (memcmp(&chunkid, "data", 4) == 0)
 		{
@@ -718,7 +678,7 @@ status _af_wave_read_init (AFfilesetup setup, AFfilehandle filehandle)
 			if (result == AF_FAIL)
 				return AF_FAIL;
 
-			hasData = AF_TRUE;
+			hasData = true;
 		}
 		else if (memcmp(&chunkid, "inst", 4) == 0)
 		{
@@ -728,35 +688,35 @@ status _af_wave_read_init (AFfilesetup setup, AFfilehandle filehandle)
 		}
 		else if (memcmp(&chunkid, "fact", 4) == 0)
 		{
-			hasFrameCount = AF_TRUE;
+			hasFrameCount = true;
 			result = ParseFrameCount(filehandle, filehandle->fh, chunkid, chunksize);
 			if (result == AF_FAIL)
 				return AF_FAIL;
 		}
 		else if (memcmp(&chunkid, "cue ", 4) == 0)
 		{
-			hasCue = AF_TRUE;
+			hasCue = true;
 			result = ParseCues(filehandle, filehandle->fh, chunkid, chunksize);
 			if (result == AF_FAIL)
 				return AF_FAIL;
 		}
 		else if (memcmp(&chunkid, "LIST", 4) == 0 || memcmp(&chunkid, "list", 4) == 0)
 		{
-			hasList = AF_TRUE;
+			hasList = true;
 			result = ParseList(filehandle, filehandle->fh, chunkid, chunksize);
 			if (result == AF_FAIL)
 				return AF_FAIL;
 		}
 		else if (memcmp(&chunkid, "INST", 4) == 0)
 		{
-			hasINST = AF_TRUE;
+			hasINST = true;
 			result = ParseInstrument(filehandle, filehandle->fh, chunkid, chunksize);
 			if (result == AF_FAIL)
 				return AF_FAIL;
 		}
 		else if (memcmp(&chunkid, "plst", 4) == 0)
 		{
-			hasPlayList = AF_TRUE;
+			hasPlayList = true;
 			result = ParsePlayList(filehandle, filehandle->fh, chunkid, chunksize);
 			if (result == AF_FAIL)
 				return AF_FAIL;
@@ -782,14 +742,10 @@ status _af_wave_read_init (AFfilesetup setup, AFfilehandle filehandle)
 		and a data chunk, so we can assume that track->f and
 		track->data_size have been initialized.
 	*/
-	if (hasFrameCount == AF_FALSE)
+	if (!hasFrameCount)
 	{
-		/*
-			Perform arithmetic in double-precision so as
-			to preserve accuracy.
-		*/
-		track->totalfframes = ceil((double) track->data_size /
-			_af_format_frame_size(&track->f, AF_FALSE));
+		track->totalfframes = track->data_size /
+			(int) _af_format_frame_size(&track->f, false);
 	}
 
 	if (track->f.compressionType != AF_COMPRESSION_NONE &&
@@ -834,8 +790,14 @@ AFfilesetup _af_wave_complete_setup (AFfilesetup setup)
 				break;
 
 			case AF_SAMPFMT_DOUBLE:
-				_af_error(AF_BAD_SAMPFMT, "WAVE format does not support double-precision floating-point data");
-				return AF_NULL_FILESETUP;
+				if (track->sampleWidthSet &&
+					track->f.sampleWidth != 64)
+				{
+					_af_error(AF_BAD_WIDTH,
+						"Warning: invalid sample width for double-precision floating-point WAVE file: %d (must be 64 bits)\n",
+						track->f.sampleWidth);
+					_af_set_sample_format(&track->f, AF_SAMPFMT_DOUBLE, 64);
+				}
 				break;
 
 			case AF_SAMPFMT_UNSIGNED:
@@ -889,7 +851,7 @@ AFfilesetup _af_wave_complete_setup (AFfilesetup setup)
 	*/
 	else
 	{
-		if (track->sampleWidthSet == AF_FALSE)
+		if (!track->sampleWidthSet)
 		{
 			track->f.sampleWidth = 16;
 			track->f.sampleFormat = AF_SAMPFMT_TWOSCOMP;
@@ -948,7 +910,7 @@ AFfilesetup _af_wave_complete_setup (AFfilesetup setup)
 		{
 			if (setup->instruments[0].loopSet &&
 				setup->instruments[0].loopCount > 0 &&
-				(track->markersSet == AF_FALSE || track->markerCount == 0))
+				(!track->markersSet || track->markerCount == 0))
 			{
 				_af_error(AF_BAD_NUMMARKS, "WAVE files with loops must contain at least 1 marker");
 				return AF_NULL_FILESETUP;
@@ -981,7 +943,7 @@ AFfilesetup _af_wave_complete_setup (AFfilesetup setup)
 	/*
 		Allocate an AFfilesetup and make all the unset fields correct.
 	*/
-	newsetup = _af_filesetup_copy(setup, &_af_wave_default_filesetup, AF_FALSE);
+	newsetup = _af_filesetup_copy(setup, &_af_wave_default_filesetup, false);
 
 	/* Make sure we do not copy loops if they are not specified in setup. */
 	if (setup->instrumentSet && setup->instrumentCount > 0 &&
@@ -1001,7 +963,7 @@ bool _af_wave_instparam_valid (AFfilehandle filehandle, AUpvlist list, int i)
 	AUpvgetparam(list, i, &param);
 	AUpvgetvaltype(list, i, &type);
 	if (type != AU_PVTYPE_LONG)
-		return AF_FALSE;
+		return false;
 
 	AUpvgetval(list, i, &lval);
 
@@ -1026,11 +988,11 @@ bool _af_wave_instparam_valid (AFfilehandle filehandle, AUpvlist list, int i)
 			return ((lval >= 0) && (lval <= 127));
 
 		case AF_INST_NUMDBS_GAIN:
-			return AF_TRUE;
+			return true;
 
 		default:
-			return AF_FALSE;
+			return false;
 	}
 
-	return AF_TRUE;
+	return true;
 }
