@@ -80,7 +80,7 @@ enum
 bool _af_wave_recognize (AFvirtualfile *fh);
 status _af_wave_read_init (AFfilesetup, AFfilehandle);
 status _af_wave_write_init (AFfilesetup, AFfilehandle);
-bool _af_wave_update (AFfilehandle);
+status _af_wave_update (AFfilehandle);
 AFfilesetup _af_wave_complete_setup (AFfilesetup);
 bool _af_wave_instparam_valid (AFfilehandle, AUpvlist, int);
 
@@ -96,11 +96,11 @@ typedef struct _WAVEInfo
 		The following information is specified in the format
 		chunk and is for use with compressed data formats.
 	*/
-	u_int32_t	blockAlign, samplesPerBlock;
+	uint32_t	blockAlign, samplesPerBlock;
 
 	/*
 		The index into the coefficient array is of type
-		u_int8_t, so we can safely limit msadpcmCoefficients to
+		uint8_t, so we can safely limit msadpcmCoefficients to
 		be 256 coefficient pairs.
 	*/
 	int16_t		msadpcmCoefficients[256][2];
